# SPDX-License-Identifier: MIT
---
- name: Test basic services of the role are installed and running
  hosts: all
  vars:
    # test to install selinux but not firewall
    metrics_manage_firewall: false
    metrics_manage_selinux: true

  pre_tasks:
    - name: Save state of services
      import_tasks: get_services_state.yml

  tasks:
    - name: Run test
      block:
        - name: Run the role
          include_role:
            name: linux-system-roles.metrics
            public: true

        - name: Check if basic metrics role setup works
          include_tasks: "{{ item }}"
          loop:
            - check_pcp.yml
            - check_pmlogger.yml
            - check_pmie.yml
            - check_firewall_selinux.yml

        - name: Flush handlers
          meta: flush_handlers

      rescue:
        - name: Handle failure case
          include_tasks: handle_test_failure.yml

      always:
        - name: Restore state of services
          import_tasks: restore_services_state.yml
